@@ -23,11 +23,13 @@ fn add_managed_type(substitutions: &mut SubstitutionsMap, type_name: &proc_macro
 
 fn add_managed_type_with_generics(
     substitutions: &mut SubstitutionsMap,
-    alias: &proc_macro2::TokenStream,
     type_name: &proc_macro2::TokenStream,
 ) {
-    substitutions.add_substitution(quote!(#alias<Self::Api, ), quote!(#type_name<Self::Api, ));
-    substitutions.add_substitution(quote!(#alias<), quote!(#type_name<Self::Api, ));
+    substitutions.add_substitution(
+        quote!(#type_name<Self::Api, ),
+        quote!(#type_name<Self::Api, ),
+    );
+    substitutions.add_substitution(quote!(#type_name<), quote!(#type_name<Self::Api, ));
 }
 
 fn add_managed_types(substitutions: &mut SubstitutionsMap) {
@@ -41,22 +43,12 @@ fn add_managed_types(substitutions: &mut SubstitutionsMap) {
     add_managed_type(substitutions, &quote!(AsyncCall));
     add_managed_type(substitutions, &quote!(ManagedAsyncCallError));
 
-    add_managed_type_with_generics(substitutions, &quote!(ManagedVec), &quote!(ManagedVec));
-    add_managed_type_with_generics(
-        substitutions,
-        &quote!(ManagedVarArgs),
-        &quote!(ManagedMultiResultVec),
-    );
-    add_managed_type_with_generics(
-        substitutions,
-        &quote!(ManagedMultiResultVec),
-        &quote!(ManagedMultiResultVec),
-    );
-    add_managed_type_with_generics(
-        substitutions,
-        &quote!(ManagedAsyncCallResult),
-        &quote!(ManagedAsyncCallResult),
-    );
+    add_managed_type_with_generics(substitutions, &quote!(ManagedVec));
+    add_managed_type_with_generics(substitutions, &quote!(ManagedVarArgs));
+    add_managed_type_with_generics(substitutions, &quote!(ManagedMultiResultVec));
+    add_managed_type_with_generics(substitutions, &quote!(ManagedAsyncCallResult));
+    add_managed_type_with_generics(substitutions, &quote!(ManagedCountedVarArgs));
+    add_managed_type_with_generics(substitutions, &quote!(ManagedCountedMultiResultVec));
 }
 
 fn add_special_methods(substitutions: &mut SubstitutionsMap) {
@@ -84,6 +76,10 @@ fn add_special_methods(substitutions: &mut SubstitutionsMap) {
         quote!(ManagedVec::new()),
         quote!(self.types().managed_vec_new()),
     );
+    substitutions.add_substitution(
+        quote!(ManagedVec::from_single_item),
+        quote!(self.types().managed_vec_from_single_item),
+    );
     substitutions.add_substitution(
         quote!(ManagedVec::from),
         quote!(self.types().managed_vec_from),
@@ -125,7 +121,7 @@ fn add_storage_mapper(
     substitutions: &mut SubstitutionsMap,
     mapper_name: &proc_macro2::TokenStream,
 ) {
-    add_managed_type_with_generics(substitutions, mapper_name, mapper_name);
+    add_managed_type_with_generics(substitutions, mapper_name);
 }
 
 fn add_storage_mappers(substitutions: &mut SubstitutionsMap) {
